@@ -1,31 +1,20 @@
-/*  This file is part of the KDE libraries
- *  Copyright (C) 2000 Waldo Bastian <bastian@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- **/
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "kservicegroup.h"
-#include "kservicegroup_p.h"
-#include "kservicefactory_p.h"
-#include "kservicegroupfactory_p.h"
 #include "kservice.h"
+#include "kservicefactory_p.h"
+#include "kservicegroup_p.h"
+#include "kservicegroupfactory_p.h"
 #include "ksycoca_p.h"
 #include "servicesdebug.h"
+#include <KConfigGroup>
+#include <KDesktopFile>
 #include <ksycoca.h>
-#include <kdesktopfile.h>
-#include <kconfiggroup.h>
 
 KServiceGroup::KServiceGroup(const QString &name)
     : KSycocaEntry(*new KServiceGroupPrivate(name))
@@ -65,11 +54,11 @@ void KServiceGroupPrivate::load(const QString &cfg)
     if (m_strCaption.isEmpty()) {
         m_strCaption = path;
         if (m_strCaption.endsWith(QLatin1Char('/'))) {
-            m_strCaption = m_strCaption.left(m_strCaption.length() - 1);
+            m_strCaption.chop(1);
         }
         int i = m_strCaption.lastIndexOf(QLatin1Char('/'));
         if (i > 0) {
-            m_strCaption = m_strCaption.mid(i + 1);
+            m_strCaption.remove(0, i + 1);
         }
     }
     if (m_strIcon.isEmpty()) {
@@ -77,8 +66,8 @@ void KServiceGroupPrivate::load(const QString &cfg)
     }
 }
 
-KServiceGroup::KServiceGroup(QDataStream &_str, int offset, bool deep) :
-    KSycocaEntry(*new KServiceGroupPrivate(_str, offset))
+KServiceGroup::KServiceGroup(QDataStream &_str, int offset, bool deep)
+    : KSycocaEntry(*new KServiceGroupPrivate(_str, offset))
 {
     Q_D(KServiceGroup);
     d->m_bDeep = deep;
@@ -123,16 +112,15 @@ int KServiceGroupPrivate::childCount() const
     if (m_childCount == -1) {
         m_childCount = 0;
 
-        for (KServiceGroup::List::ConstIterator it = m_serviceList.begin();
-                it != m_serviceList.end(); ++it) {
+        for (KServiceGroup::List::ConstIterator it = m_serviceList.begin(); it != m_serviceList.end(); ++it) {
             KSycocaEntry::Ptr p = *it;
             if (p->isType(KST_KService)) {
-                KService::Ptr service(static_cast<KService*>(p.data()));
+                KService::Ptr service(static_cast<KService *>(p.data()));
                 if (!service->noDisplay()) {
                     m_childCount++;
                 }
             } else if (p->isType(KST_KServiceGroup)) {
-                KServiceGroup::Ptr serviceGroup(static_cast<KServiceGroup*>(p.data()));
+                KServiceGroup::Ptr serviceGroup(static_cast<KServiceGroup *>(p.data()));
                 m_childCount += serviceGroup->childCount();
             }
         }
@@ -220,10 +208,8 @@ void KServiceGroupPrivate::load(QDataStream &s)
     qint8 inlineHeader;
     qint8 _inlineAlias;
     qint8 _allowInline;
-    s >> m_strCaption >> m_strIcon >>
-      m_strComment >> groupList >> m_strBaseGroupName >> m_childCount >>
-      noDisplay >> suppressGenericNames >> directoryEntryPath >>
-      sortOrder >> _showEmptyMenu >> inlineHeader >> _inlineAlias >> _allowInline;
+    s >> m_strCaption >> m_strIcon >> m_strComment >> groupList >> m_strBaseGroupName >> m_childCount >> noDisplay >> suppressGenericNames >> directoryEntryPath
+        >> sortOrder >> _showEmptyMenu >> inlineHeader >> _inlineAlias >> _allowInline;
 
     m_bNoDisplay = (noDisplay != 0);
     m_bShowEmptyMenu = (_showEmptyMenu != 0);
@@ -232,7 +218,7 @@ void KServiceGroupPrivate::load(QDataStream &s)
     m_bAllowInline = (_allowInline != 0);
 
     if (m_bDeep) {
-        Q_FOREACH (const QString &path, groupList) {
+        for (const QString &path : qAsConst(groupList)) {
             if (path.endsWith(QLatin1Char('/'))) {
                 KServiceGroup::Ptr serviceGroup;
                 serviceGroup = KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(path, false);
@@ -261,29 +247,27 @@ void KServiceGroupPrivate::save(QDataStream &s)
     KSycocaEntryPrivate::save(s);
 
     QStringList groupList;
-    Q_FOREACH (KSycocaEntry::Ptr p, m_serviceList) {
+    for (const KSycocaEntry::Ptr &p : qAsConst(m_serviceList)) {
         if (p->isType(KST_KService)) {
-            KService::Ptr service(static_cast<KService*>(p.data()));
+            KService::Ptr service(static_cast<KService *>(p.data()));
             groupList.append(service->entryPath());
         } else if (p->isType(KST_KServiceGroup)) {
-            KServiceGroup::Ptr serviceGroup(static_cast<KServiceGroup*>(p.data()));
+            KServiceGroup::Ptr serviceGroup(static_cast<KServiceGroup *>(p.data()));
             groupList.append(serviceGroup->relPath());
         } else {
-            //fprintf(stderr, "KServiceGroup: Unexpected object in list!\n");
+            // fprintf(stderr, "KServiceGroup: Unexpected object in list!\n");
         }
     }
 
-    (void) childCount();
+    (void)childCount();
 
     qint8 noDisplay = m_bNoDisplay ? 1 : 0;
     qint8 _showEmptyMenu = m_bShowEmptyMenu ? 1 : 0;
     qint8 inlineHeader = m_bShowInlineHeader ? 1 : 0;
     qint8 _inlineAlias = m_bInlineAlias ? 1 : 0;
     qint8 _allowInline = m_bAllowInline ? 1 : 0;
-    s << m_strCaption << m_strIcon <<
-      m_strComment << groupList << m_strBaseGroupName << m_childCount <<
-      noDisplay << suppressGenericNames << directoryEntryPath <<
-      sortOrder << _showEmptyMenu << inlineHeader << _inlineAlias << _allowInline;
+    s << m_strCaption << m_strIcon << m_strComment << groupList << m_strBaseGroupName << m_childCount << noDisplay << suppressGenericNames << directoryEntryPath
+      << sortOrder << _showEmptyMenu << inlineHeader << _inlineAlias << _allowInline;
 }
 
 QList<KServiceGroup::Ptr> KServiceGroup::groupEntries(EntriesOptions options)
@@ -291,10 +275,10 @@ QList<KServiceGroup::Ptr> KServiceGroup::groupEntries(EntriesOptions options)
     Q_D(KServiceGroup);
     bool sort = options & SortEntries || options & AllowSeparators;
     QList<KServiceGroup::Ptr> list;
-    List tmp = d->entries(this, sort, options & ExcludeNoDisplay, options & AllowSeparators, options & SortByGenericName);
-    foreach (const SPtr &ptr, tmp) {
+    const List tmp = d->entries(this, sort, options & ExcludeNoDisplay, options & AllowSeparators, options & SortByGenericName);
+    for (const SPtr &ptr : tmp) {
         if (ptr->isType(KST_KServiceGroup)) {
-            KServiceGroup::Ptr serviceGroup(static_cast<KServiceGroup*>(ptr.data()));
+            KServiceGroup::Ptr serviceGroup(static_cast<KServiceGroup *>(ptr.data()));
             list.append(serviceGroup);
         } else if (ptr->isType(KST_KServiceSeparator)) {
             list.append(KServiceGroup::Ptr(static_cast<KServiceGroup *>(new KSycocaEntry())));
@@ -310,11 +294,11 @@ KService::List KServiceGroup::serviceEntries(EntriesOptions options)
     Q_D(KServiceGroup);
     bool sort = options & SortEntries || options & AllowSeparators;
     QList<KService::Ptr> list;
-    List tmp = d->entries(this, sort, options & ExcludeNoDisplay, options & AllowSeparators, options & SortByGenericName);
+    const List tmp = d->entries(this, sort, options & ExcludeNoDisplay, options & AllowSeparators, options & SortByGenericName);
     bool foundService = false;
-    foreach (const SPtr &ptr, tmp) {
+    for (const SPtr &ptr : tmp) {
         if (ptr->isType(KST_KService)) {
-            list.append(KService::Ptr(static_cast<KService*>(ptr.data())));
+            list.append(KService::Ptr(static_cast<KService *>(ptr.data())));
             foundService = true;
         } else if (ptr->isType(KST_KServiceSeparator) && foundService) {
             list.append(KService::Ptr(static_cast<KService *>(new KSycocaEntry())));
@@ -323,22 +307,19 @@ KService::List KServiceGroup::serviceEntries(EntriesOptions options)
     return list;
 }
 
-KServiceGroup::List
-KServiceGroup::entries(bool sort)
+KServiceGroup::List KServiceGroup::entries(bool sort)
 {
     Q_D(KServiceGroup);
     return d->entries(this, sort, true, false, false);
 }
 
-KServiceGroup::List
-KServiceGroup::entries(bool sort, bool excludeNoDisplay)
+KServiceGroup::List KServiceGroup::entries(bool sort, bool excludeNoDisplay)
 {
     Q_D(KServiceGroup);
     return d->entries(this, sort, excludeNoDisplay, false, false);
 }
 
-KServiceGroup::List
-KServiceGroup::entries(bool sort, bool excludeNoDisplay, bool allowSeparators, bool sortByGenericName)
+KServiceGroup::List KServiceGroup::entries(bool sort, bool excludeNoDisplay, bool allowSeparators, bool sortByGenericName)
 {
     Q_D(KServiceGroup);
     return d->entries(this, sort, excludeNoDisplay, allowSeparators, sortByGenericName);
@@ -353,8 +334,7 @@ static void addItem(KServiceGroup::List &sorted, const KSycocaEntry::Ptr &p, boo
     addSeparator = false;
 }
 
-KServiceGroup::List
-KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDisplay, bool allowSeparators, bool sortByGenericName)
+KServiceGroup::List KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDisplay, bool allowSeparators, bool sortByGenericName)
 {
     KSycoca::self()->ensureCacheValid();
 
@@ -383,10 +363,9 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
     typedef QMap<QByteArray, KServiceGroup::SPtr> SortedContainer;
     SortedContainer slist;
     SortedContainer glist;
-    Q_FOREACH (KSycocaEntry::Ptr p, group->d_func()->m_serviceList) {
-        bool noDisplay = p->isType(KST_KServiceGroup) ?
-                         static_cast<KServiceGroup *>(p.data())->noDisplay() :
-                         static_cast<KService *>(p.data())->noDisplay();
+    const auto listService = group->d_func()->m_serviceList;
+    for (const KSycocaEntry::Ptr &p : listService) {
+        bool noDisplay = p->isType(KST_KServiceGroup) ? static_cast<KServiceGroup *>(p.data())->noDisplay() : static_cast<KService *>(p.data())->noDisplay();
         if (excludeNoDisplay && noDisplay) {
             continue;
         }
@@ -429,7 +408,7 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
     if (sortOrder.isEmpty()) {
         sortOrder << QStringLiteral(":M");
         sortOrder << QStringLiteral(":F");
-        sortOrder << QStringLiteral(":OIH IL[4]"); //just inline header
+        sortOrder << QStringLiteral(":OIH IL[4]"); // just inline header
     }
 
     QString rp = path;
@@ -439,15 +418,15 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
 
     // Iterate through the sort spec list.
     // If an entry gets mentioned explicitly, we remove it from the sorted list
-    Q_FOREACH (const QString &item, sortOrder) {
+    for (const QString &item : qAsConst(sortOrder)) {
         if (item.isEmpty()) {
             continue;
         }
         if (item[0] == QLatin1Char('/')) {
-            QString groupPath = rp + item.mid(1) + QLatin1Char('/');
+            QString groupPath = rp + item.midRef(1) + QLatin1Char('/');
             // Remove entry from sorted list of services.
             for (SortedContainer::iterator it2 = glist.begin(); it2 != glist.end(); ++it2) {
-                const KServiceGroup::Ptr group(static_cast<KServiceGroup*>(it2.value().data()));
+                const KServiceGroup::Ptr group(static_cast<KServiceGroup *>(it2.value().data()));
                 if (group->relPath() == groupPath) {
                     glist.erase(it2);
                     break;
@@ -458,7 +437,7 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
             // TODO: Remove item from sortOrder-list if not found
             // TODO: This prevents duplicates
             for (SortedContainer::iterator it2 = slist.begin(); it2 != slist.end(); ++it2) {
-                const KService::Ptr service(static_cast<KService*>(it2.value().data()));
+                const KService::Ptr service(static_cast<KService *>(it2.value().data()));
                 if (service->menuId() == item) {
                     slist.erase(it2);
                     break;
@@ -484,10 +463,10 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
                     needSeparator = true;
                 }
             } else if (item.contains(QLatin1String(":O"))) {
-                //todo parse attribute:
+                // todo parse attribute:
                 QString tmp(item);
-                tmp = tmp.remove(QStringLiteral(":O"));
-                QStringList optionAttribute = tmp.split(QLatin1Char(' '), QString::SkipEmptyParts);
+                tmp.remove(QStringLiteral(":O"));
+                QStringList optionAttribute = tmp.split(QLatin1Char(' '), Qt::SkipEmptyParts);
                 if (optionAttribute.isEmpty()) {
                     optionAttribute.append(tmp);
                 }
@@ -498,10 +477,10 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
                 int inlineValue = -1;
 
                 for (QStringList::Iterator it3 = optionAttribute.begin(); it3 != optionAttribute.end(); ++it3) {
-                    parseAttribute(*it3,  showEmptyMenu, showInline, showInlineHeader, showInlineAlias, inlineValue);
+                    parseAttribute(*it3, showEmptyMenu, showInline, showInlineHeader, showInlineAlias, inlineValue);
                 }
                 for (SortedContainer::Iterator it2 = glist.begin(); it2 != glist.end(); ++it2) {
-                    KServiceGroup::Ptr group(static_cast<KServiceGroup*>(it2.value().data()));
+                    KServiceGroup::Ptr group(static_cast<KServiceGroup *>(it2.value().data()));
                     group->setShowEmptyMenu(showEmptyMenu);
                     group->setAllowInline(showInline);
                     group->setShowInlineHeader(showInlineHeader);
@@ -527,7 +506,7 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
                 while (true) {
                     if (it_s == slist.end()) {
                         if (it_g == glist.end()) {
-                            break;    // Done
+                            break; // Done
                         }
 
                         // Insert remaining sub-menu
@@ -549,24 +528,22 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
                 }
             }
         } else if (item[0] == QLatin1Char('/')) {
-            QString groupPath = rp + item.mid(1) + QLatin1Char('/');
+            QString groupPath = rp + item.midRef(1) + QLatin1Char('/');
 
-            for (KServiceGroup::List::ConstIterator it2(group->d_func()->m_serviceList.constBegin());
-                    it2 != group->d_func()->m_serviceList.constEnd(); ++it2) {
+            for (KServiceGroup::List::ConstIterator it2(group->d_func()->m_serviceList.constBegin()); it2 != group->d_func()->m_serviceList.constEnd(); ++it2) {
                 if (!(*it2)->isType(KST_KServiceGroup)) {
                     continue;
                 }
-                KServiceGroup::Ptr group(static_cast<KServiceGroup*>((*it2).data()));
+                KServiceGroup::Ptr group(static_cast<KServiceGroup *>((*it2).data()));
                 if (group->relPath() == groupPath) {
                     if (!excludeNoDisplay || !group->noDisplay()) {
                         ++it;
-                        const QString &nextItem =
-                            (it == sortOrder.constEnd()) ? QString() : *it;
+                        const QString &nextItem = (it == sortOrder.constEnd()) ? QString() : *it;
 
                         if (nextItem.startsWith(QLatin1String(":O"))) {
                             QString tmp(nextItem);
-                            tmp = tmp.remove(QStringLiteral(":O"));
-                            QStringList optionAttribute = tmp.split(QLatin1Char(' '), QString::SkipEmptyParts);
+                            tmp.remove(QStringLiteral(":O"));
+                            QStringList optionAttribute = tmp.split(QLatin1Char(' '), Qt::SkipEmptyParts);
                             if (optionAttribute.isEmpty()) {
                                 optionAttribute.append(tmp);
                             }
@@ -575,7 +552,7 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
                             bool bShowInlineHeader = false;
                             bool bShowInlineAlias = false;
                             int inlineValue = -1;
-                            Q_FOREACH (const QString &opt_attr, optionAttribute) {
+                            for (const QString &opt_attr : qAsConst(optionAttribute)) {
                                 parseAttribute(opt_attr, bShowEmptyMenu, bShowInline, bShowInlineHeader, bShowInlineAlias, inlineValue);
                                 group->setShowEmptyMenu(bShowEmptyMenu);
                                 group->setAllowInline(bShowInline);
@@ -593,12 +570,11 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
                 }
             }
         } else {
-            for (KServiceGroup::List::ConstIterator it2(group->d_func()->m_serviceList.constBegin());
-                    it2 != group->d_func()->m_serviceList.constEnd(); ++it2) {
+            for (KServiceGroup::List::ConstIterator it2(group->d_func()->m_serviceList.constBegin()); it2 != group->d_func()->m_serviceList.constEnd(); ++it2) {
                 if (!(*it2)->isType(KST_KService)) {
                     continue;
                 }
-                const KService::Ptr service(static_cast<KService*>((*it2).data()));
+                const KService::Ptr service(static_cast<KService *>((*it2).data()));
                 if (service->menuId() == item) {
                     if (!excludeNoDisplay || !service->noDisplay()) {
                         addItem(sorted, (*it2), needSeparator);
@@ -612,34 +588,39 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
     return sorted;
 }
 
-void KServiceGroupPrivate::parseAttribute(const QString &item,  bool &showEmptyMenu, bool &showInline, bool &showInlineHeader, bool &showInlineAlias, int &inlineValue)
+void KServiceGroupPrivate::parseAttribute(const QString &item,
+                                          bool &showEmptyMenu,
+                                          bool &showInline,
+                                          bool &showInlineHeader,
+                                          bool &showInlineAlias,
+                                          int &inlineValue)
 {
-    if (item == QLatin1String("ME")) { //menu empty
+    if (item == QLatin1String("ME")) { // menu empty
         showEmptyMenu = true;
-    } else if (item == QLatin1String("NME")) { //not menu empty
+    } else if (item == QLatin1String("NME")) { // not menu empty
         showEmptyMenu = false;
-    } else if (item == QLatin1String("I")) { //inline menu !
+    } else if (item == QLatin1String("I")) { // inline menu !
         showInline = true;
-    } else if (item == QLatin1String("NI")) { //not inline menu!
+    } else if (item == QLatin1String("NI")) { // not inline menu!
         showInline = false;
-    } else if (item == QLatin1String("IH")) { //inline  header!
+    } else if (item == QLatin1String("IH")) { // inline  header!
         showInlineHeader = true;
-    } else if (item == QLatin1String("NIH")) { //not inline  header!
+    } else if (item == QLatin1String("NIH")) { // not inline  header!
         showInlineHeader = false;
-    } else if (item == QLatin1String("IA")) { //inline alias!
+    } else if (item == QLatin1String("IA")) { // inline alias!
         showInlineAlias = true;
-    } else if (item == QLatin1String("NIA")) { //not inline alias!
+    } else if (item == QLatin1String("NIA")) { // not inline alias!
         showInlineAlias = false;
-    } else if ((item).contains(QLatin1String("IL"))) { //inline limite!
+    } else if ((item).contains(QLatin1String("IL"))) { // inline limite!
         QString tmp(item);
-        tmp = tmp.remove(QStringLiteral("IL["));
-        tmp = tmp.remove(QLatin1Char(']'));
+        tmp.remove(QStringLiteral("IL["));
+        tmp.remove(QLatin1Char(']'));
         bool ok;
         int _inlineValue = tmp.toInt(&ok);
-        if (!ok) { //error
+        if (!ok) { // error
             _inlineValue = -1;
         }
-        inlineValue =  _inlineValue;
+        inlineValue = _inlineValue;
     } else {
         qCDebug(SERVICES) << "This attribute is not supported:" << item;
     }
@@ -657,15 +638,13 @@ QStringList KServiceGroup::layoutInfo() const
     return d->sortOrder;
 }
 
-KServiceGroup::Ptr
-KServiceGroup::root()
+KServiceGroup::Ptr KServiceGroup::root()
 {
     KSycoca::self()->ensureCacheValid();
     return KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(QStringLiteral("/"), true);
 }
 
-KServiceGroup::Ptr
-KServiceGroup::group(const QString &relPath)
+KServiceGroup::Ptr KServiceGroup::group(const QString &relPath)
 {
     if (relPath.isEmpty()) {
         return root();
@@ -674,8 +653,7 @@ KServiceGroup::group(const QString &relPath)
     return KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(relPath, true);
 }
 
-KServiceGroup::Ptr
-KServiceGroup::childGroup(const QString &parent)
+KServiceGroup::Ptr KServiceGroup::childGroup(const QString &parent)
 {
     KSycoca::self()->ensureCacheValid();
     return KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(QLatin1String("#parent#") + parent, true);
@@ -686,8 +664,7 @@ QString KServiceGroup::baseGroupName() const
     return d_func()->m_strBaseGroupName;
 }
 
-QString
-KServiceGroup::directoryEntryPath() const
+QString KServiceGroup::directoryEntryPath() const
 {
     Q_D(const KServiceGroup);
     return d->directoryEntryPath;
@@ -711,7 +688,6 @@ QString KServiceSeparatorPrivate::name() const
     return QStringLiteral("separator");
 }
 
-
 KServiceSeparator::KServiceSeparator()
     : KSycocaEntry(*new KServiceSeparatorPrivate(QStringLiteral("separator")))
 {
@@ -720,4 +696,3 @@ KServiceSeparator::KServiceSeparator()
 KServiceSeparator::~KServiceSeparator()
 {
 }
-
